"""
rocm-vvv - Main entry point
Author: JeongHyun Kim
"""

import sys
from .checker import main

def main_entry():
    """Entry point for console scripts"""
    main()

if __name__ == "__main__":
    main_entry()
